==> org.opennms.features.discovery-19.0.0-20161003.014938-220-sources.jar: org/opennms/netmgt/discovery/UnmanagedInterfaceFilter.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2015-2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.discovery;

import java.net.InetAddress;

import org.opennms.core.utils.InetAddressUtils;
import org.opennms.netmgt.dao.api.AbstractInterfaceToNodeCache;

/**
 * Given a list of managed IP addresses, this filter will match IP addresses not in that
 * list, hence it is an unmanaged IP address filter.
 */
public class UnmanagedInterfaceFilter implements IpAddressFilter {

    @Override
    public boolean matches(String location, InetAddress address) {
        return AbstractInterfaceToNodeCache.getInstance().getNodeId(location, address) < 1;
    }

    @Override
    public boolean matches(String location, String address) {
        return matches(location, InetAddressUtils.addr(address));
    }
}

==> org.opennms.features.discovery-20.0.0-20170322.042034-123-sources.jar: org/opennms/netmgt/discovery/UnmanagedInterfaceFilter.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2015-2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.discovery;

import java.net.InetAddress;
import java.util.Objects;

import org.opennms.core.utils.InetAddressUtils;
import org.opennms.netmgt.dao.api.InterfaceToNodeCache;

/**
 * Given a list of managed IP addresses, this filter will match IP addresses not in that
 * list, hence it is an unmanaged IP address filter.
 */
public class UnmanagedInterfaceFilter implements IpAddressFilter {

    private final InterfaceToNodeCache interfaceToNodeCache;

    public UnmanagedInterfaceFilter(InterfaceToNodeCache interfaceToNodeCache) {
        this.interfaceToNodeCache = Objects.requireNonNull(interfaceToNodeCache);
    }

    @Override
    public boolean matches(String location, InetAddress address) {
        return interfaceToNodeCache.getNodeId(location, address) < 1;
    }

    @Override
    public boolean matches(String location, String address) {
        return matches(location, InetAddressUtils.addr(address));
    }
}
